# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import enum

import winrt.system
from winrt import _winrt_windows_system_profile

__all__ = [
    "PlatformAutomaticAppSignInPolicy",
    "PlatformDataCollectionLevel",
    "SystemIdentificationSource",
    "SystemOutOfBoxExperienceState",
    "UnsupportedAppRequirementReasons",
    "AnalyticsInfo",
    "AnalyticsVersionInfo",
    "AppApplicability",
    "EducationSettings",
    "HardwareIdentification",
    "HardwareToken",
    "KnownRetailInfoProperties",
    "PlatformAutomaticAppSignInManager",
    "PlatformDiagnosticsAndUsageDataSettings",
    "RetailInfo",
    "SharedModeSettings",
    "SmartAppControlPolicy",
    "SystemIdentification",
    "SystemIdentificationInfo",
    "SystemSetupInfo",
    "UnsupportedAppRequirement",
    "WindowsIntegrityPolicy",
]

class PlatformAutomaticAppSignInPolicy(enum.IntEnum):
    UNKNOWN = 0
    PERMISSION_REQUIRED = 1
    ALWAYS_ALLOWED = 2

class PlatformDataCollectionLevel(enum.IntEnum):
    SECURITY = 0
    BASIC = 1
    ENHANCED = 2
    FULL = 3

class SystemIdentificationSource(enum.IntEnum):
    NONE = 0
    TPM = 1
    UEFI = 2
    REGISTRY = 3

class SystemOutOfBoxExperienceState(enum.IntEnum):
    NOT_STARTED = 0
    IN_PROGRESS = 1
    COMPLETED = 2

class UnsupportedAppRequirementReasons(enum.IntFlag):
    UNKNOWN = 0
    DENIED_BY_SYSTEM = 0x1

AnalyticsInfo = _winrt_windows_system_profile.AnalyticsInfo
AnalyticsVersionInfo = _winrt_windows_system_profile.AnalyticsVersionInfo
AppApplicability = _winrt_windows_system_profile.AppApplicability
EducationSettings = _winrt_windows_system_profile.EducationSettings
HardwareIdentification = _winrt_windows_system_profile.HardwareIdentification
HardwareToken = _winrt_windows_system_profile.HardwareToken
KnownRetailInfoProperties = _winrt_windows_system_profile.KnownRetailInfoProperties
PlatformAutomaticAppSignInManager = _winrt_windows_system_profile.PlatformAutomaticAppSignInManager
PlatformDiagnosticsAndUsageDataSettings = _winrt_windows_system_profile.PlatformDiagnosticsAndUsageDataSettings
RetailInfo = _winrt_windows_system_profile.RetailInfo
SharedModeSettings = _winrt_windows_system_profile.SharedModeSettings
SmartAppControlPolicy = _winrt_windows_system_profile.SmartAppControlPolicy
SystemIdentification = _winrt_windows_system_profile.SystemIdentification
SystemIdentificationInfo = _winrt_windows_system_profile.SystemIdentificationInfo
SystemSetupInfo = _winrt_windows_system_profile.SystemSetupInfo
UnsupportedAppRequirement = _winrt_windows_system_profile.UnsupportedAppRequirement
WindowsIntegrityPolicy = _winrt_windows_system_profile.WindowsIntegrityPolicy
